appcli

package
v0.8.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 5, 2026 License: MIT Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InstallCompletion added in v0.4.4

func InstallCompletion(meta *Metadata) error

InstallCompletion installs command line tab completion for a given shell.

func IsCompleting added in v0.6.0

func IsCompleting(args []string) bool

IsCompleting returns whether tab-completion is currently occurring.

func NewApp

func NewApp(args []string, meta *Metadata) (*cli.App, error)

NewApp creates a cli.App that executes tasks.

func ShowAppHelp added in v0.1.3

func ShowAppHelp(logger *ui.Logger, app *cli.App)

ShowAppHelp shows the help for a given app.

func UninstallCompletion added in v0.4.4

func UninstallCompletion(meta *Metadata) error

UninstallCompletion uninstalls command line tab completion for a given shell.

Types

type Metadata added in v0.8.0

type Metadata struct {
	CfgPath     string
	CfgText     []byte
	Interpreter []string
	Logger      *ui.Logger

	InstallCompletion   string
	UninstallCompletion string
	PrintHelp           bool
	PrintVersion        bool
	CleanCache          bool
	CleanProjectCache   bool
	CleanTaskCache      string
}

Metadata contains global configuration settings.

func NewConfiglessMetadata added in v0.8.0

func NewConfiglessMetadata(logger *ui.Logger) *Metadata

NewConfiglessMetadata returns a metadata object with application defaults, without any user configuration. This can be used to provide basic functionality in case of user error.

func NewMetadata added in v0.8.0

func NewMetadata(logger *ui.Logger, args []string) (*Metadata, error)

NewMetadata returns a metadata object based on global options passed.

Jump to